==> nextcloud-app-calendar-1:5.5.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/be.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Каляндар",
    "Confirm" : "Пацвердзіць",
    "Description:" : "Апісанне:",
    "Date:" : "Дата:",
    "Where:" : "Дзе:",
    "Event" : "Падзея",
    "Today" : "Сёння",
    "Year" : "Год",
    "Preview" : "Перадпрагляд",
    "Copy link" : "Скапіяваць спасылку",
    "Edit" : "Рэдагаваць",
    "Delete" : "Выдаліць",
    "Untitled calendar" : "Каляндар без назвы",
    "Calendars" : "Календары",
    "Export" : "Экспарт",
    "Name" : "Назва",
    "Deleted" : "Выдалены",
    "Restore" : "Аднавіць",
    "Delete permanently" : "Выдаліць назаўжды",
    "Share link" : "Абагуліць спасылку",
    "Copy public link" : "Скапіяваць публічную спасылку",
    "No users or groups" : "Няма карыстальнікаў або груп",
    "Save" : "Захаваць",
    "Filename" : "Назва файла",
    "Cancel" : "Скасаваць",
    "Navigation" : "Навігацыя",
    "Actions" : "Дзеянні",
    "Close editor" : "Закрыць рэдактар",
    "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
    "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} хвіліна","{duration} хвіліны","{duration} хвілін","{duration} хвілін"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} гадзіна","{duration} гадзіны","{duration} гадзін","{duration} гадзін"],
    "_{duration} day_::_{duration} days_" : ["{duration} дзень","{duration} дні","{duration} дзён","{duration} дзён"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} тыдзень","{duration} тыдні","{duration} тыдняў","{duration} тыдняў"],
    "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяцы","{duration} месяцаў","{duration} месяцаў"],
    "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} гады","{duration} гадоў","{duration} гадоў"],
    "Update" : "Абнавіць",
    "Location" : "Месцазнаходжанне",
    "Description" : "Апісанне",
    "Duration" : "Працягласць",
    "Add" : "Дадаць",
    "Monday" : "Панядзелак",
    "Tuesday" : "Аўторак",
    "Wednesday" : "Серада",
    "Thursday" : "Чацвер",
    "Friday" : "Пятніца",
    "Saturday" : "Субота",
    "Sunday" : "Нядзеля",
    "Your name" : "Ваша імя",
    "Back" : "Назад",
    "Notification" : "Апавяшчэнне",
    "Email" : "Электронная пошта",
    "seconds" : "с",
    "Upload from device" : "Запампаваць з прылады",
    "Delete file" : "Выдаліць файл",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Done" : "Гатова",
    "Busy" : "Заняты",
    "Unknown" : "Невядомы",
    "Accept" : "Прыняць",
    "Decline" : "Адхіліць",
    "Remove group" : "Выдаліць групу",
    "_%n member_::_%n members_" : ["%n удзельнік","%n удзельнікі","%n удзельнікаў","%n удзельнікаў"],
    "From" : "З",
    "To" : "Да",
    "never" : "ніколі",
    "Resources" : "Рэсурсы",
    "Global" : "Глабальны",
    "Public calendars" : "Публічныя календары",
    "Invite" : "Запрасіць",
    "Close" : "Закрыць",
    "Daily" : "Штодня",
    "Weekly" : "Штотыдзень",
    "Monthly" : "Штомесяц",
    "Yearly" : "Штогод",
    "_Every %n day_::_Every %n days_" : ["Кожны %n дзень","Кожныя %n дні","Кожныя %n дзён","Кожныя %n дзён"],
    "_Every %n week_::_Every %n weeks_" : ["Кожны %n тыдзень","Кожныя %n тыдні","Кожныя %n тыдняў","Кожныя %n тыдняў"],
    "_Every %n month_::_Every %n months_" : ["Кожны %n месяц","Кожныя %n месяцы","Кожныя %n месяцаў","Кожныя %n месяцаў"],
    "_Every %n year_::_Every %n years_" : ["Кожны %n год","Кожныя %n года","Кожныя %n гадоў","Кожныя %n гадоў"],
    "_%n time_::_%n times_" : ["%n раз","%n разы","%n разоў","%n разоў"],
    "Untitled task" : "Задача без назвы",
    "%n more" : "%n яшчэ",
    "_+%n more_::_+%n more_" : ["+%n яшчэ","+%n яшчэ","+%n яшчэ","+%n яшчэ"],
    "Status" : "Стан",
    "Confirmed" : "Пацверджана",
    "Canceled" : "Скасавана",
    "Categories" : "Катэгорыі",
    "User not found" : "Карыстальнік не знойдзены"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-calendar-1:5.5.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/be.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Каляндар",
    "Confirm" : "Пацвердзіць",
    "Description:" : "Апісанне:",
    "Date:" : "Дата:",
    "Where:" : "Дзе:",
    "Location:" : "Месцазнаходжанне:",
    "Duration:" : "Працягласць:",
    "Dates:" : "Даты:",
    "Event" : "Падзея",
    "Today" : "Сёння",
    "Year" : "Год",
    "Preview" : "Перадпрагляд",
    "Copy link" : "Скапіяваць спасылку",
    "Edit" : "Рэдагаваць",
    "Delete" : "Выдаліць",
    "Untitled calendar" : "Каляндар без назвы",
    "Calendars" : "Календары",
    "Export" : "Экспарт",
    "Name" : "Назва",
    "Deleted" : "Выдалены",
    "Restore" : "Аднавіць",
    "Delete permanently" : "Выдаліць назаўжды",
    "Share link" : "Абагуліць спасылку",
    "Copy public link" : "Скапіяваць публічную спасылку",
    "Unshare with {displayName}" : "Скасаваць абагульванне з {displayName}",
    "No users or groups" : "Няма карыстальнікаў або груп",
    "Unshare from me" : "Скасаваць абагульванне са мной",
    "Save" : "Захаваць",
    "View" : "Праглядзець",
    "Filename" : "Назва файла",
    "Cancel" : "Скасаваць",
    "Timezone" : "Часавы пояс",
    "Navigation" : "Навігацыя",
    "Actions" : "Дзеянні",
    "Close editor" : "Закрыць рэдактар",
    "General" : "Агульныя",
    "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
    "Keyboard shortcuts" : "Спалучэнні клавіш",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} хвіліна","{duration} хвіліны","{duration} хвілін","{duration} хвілін"],
    "_{duration} hour_::_{duration} hours_" : ["{duration} гадзіна","{duration} гадзіны","{duration} гадзін","{duration} гадзін"],
    "_{duration} day_::_{duration} days_" : ["{duration} дзень","{duration} дні","{duration} дзён","{duration} дзён"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} тыдзень","{duration} тыдні","{duration} тыдняў","{duration} тыдняў"],
    "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяцы","{duration} месяцаў","{duration} месяцаў"],
    "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} гады","{duration} гадоў","{duration} гадоў"],
    "Update" : "Абнавіць",
    "Location" : "Месцазнаходжанне",
    "Description" : "Апісанне",
    "Duration" : "Працягласць",
    "Add" : "Дадаць",
    "Monday" : "Панядзелак",
    "Tuesday" : "Аўторак",
    "Wednesday" : "Серада",
    "Thursday" : "Чацвер",
    "Friday" : "Пятніца",
    "Saturday" : "Субота",
    "Sunday" : "Нядзеля",
    "Your name" : "Ваша імя",
    "Back" : "Назад",
    "Notification" : "Апавяшчэнне",
    "Email" : "Электронная пошта",
    "seconds" : "с",
    "Upload from device" : "Запампаваць з прылады",
    "Delete file" : "Выдаліць файл",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Out of office" : "Па-за офісам",
    "Done" : "Гатова",
    "Busy" : "Заняты",
    "Unknown" : "Невядомы",
    "Accept" : "Прыняць",
    "Decline" : "Адхіліць",
    "Remove group" : "Выдаліць групу",
    "_%n member_::_%n members_" : ["%n удзельнік","%n удзельнікі","%n удзельнікаў","%n удзельнікаў"],
    "From" : "З",
    "To" : "Да",
    "never" : "ніколі",
    "Resources" : "Рэсурсы",
    "Remove participant" : "Выдаліць удзельніка",
    "Yes" : "Так",
    "No" : "Не",
    "Create" : "Ствараць",
    "Global" : "Глабальны",
    "Public calendars" : "Публічныя календары",
    "Invite" : "Запрасіць",
    "Close" : "Закрыць",
    "Selected" : "Выбрана",
    "Title" : "Загаловак",
    "15 min" : "15 хв",
    "30 min" : "30 хв",
    "60 min" : "60 хв",
    "90 min" : "90 хв",
    "Participants" : "Удзельнікі",
    "Submit" : "Адправіць",
    "Daily" : "Штодня",
    "Weekly" : "Штотыдзень",
    "Monthly" : "Штомесяц",
    "Yearly" : "Штогод",
    "_Every %n day_::_Every %n days_" : ["Кожны %n дзень","Кожныя %n дні","Кожныя %n дзён","Кожныя %n дзён"],
    "_Every %n week_::_Every %n weeks_" : ["Кожны %n тыдзень","Кожныя %n тыдні","Кожныя %n тыдняў","Кожныя %n тыдняў"],
    "_Every %n month_::_Every %n months_" : ["Кожны %n месяц","Кожныя %n месяцы","Кожныя %n месяцаў","Кожныя %n месяцаў"],
    "_Every %n year_::_Every %n years_" : ["Кожны %n год","Кожныя %n года","Кожныя %n гадоў","Кожныя %n гадоў"],
    "_%n time_::_%n times_" : ["%n раз","%n разы","%n разоў","%n разоў"],
    "Untitled task" : "Задача без назвы",
    "%n more" : "%n яшчэ",
    "_+%n more_::_+%n more_" : ["+%n яшчэ","+%n яшчэ","+%n яшчэ","+%n яшчэ"],
    "Status" : "Статус",
    "Confirmed" : "Пацверджана",
    "Canceled" : "Скасавана",
    "Categories" : "Катэгорыі",
    "User not found" : "Карыстальнік не знойдзены",
    "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
